/* vifm
 * Copyright (C) 2001 Ken Steen.
 * Copyright (C) 2011 xaizek.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
 */

#ifndef VIFM__MENUS__ALL_H__
#define VIFM__MENUS__ALL_H__

#include "apropos_menu.h"
#include "bookmarks_menu.h"
#include "colorscheme_menu.h"
#include "commands_menu.h"
#include "dirhistory_menu.h"
#include "dirstack_menu.h"
#include "filetypes_menu.h"
#include "find_menu.h"
#include "grep_menu.h"
#include "history_menu.h"
#include "jobs_menu.h"
#include "locate_menu.h"
#include "map_menu.h"
#include "registers_menu.h"
#include "trash_menu.h"
#include "trashes_menu.h"
#include "undolist_menu.h"
#include "users_menu.h"
#include "vifm_menu.h"
#include "volumes_menu.h"

#endif /* VIFM__MENUS__ALL_H__ */

/* vim: set tabstop=2 softtabstop=2 shiftwidth=2 noexpandtab cinoptions-=(0 : */
/* vim: set cinoptions+=t0 : */
